==> huaweicloudsdkgaussdb-3.1.111-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/sync_star_rocks_users_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SyncStarRocksUsersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'success': 'str'
    }

    attribute_map = {
        'success': 'success'
    }

    def __init__(self, success=None):
        """SyncStarRocksUsersResponse

        The model defined in huaweicloud sdk

        :param success: 开启行列分流是否成功。
        :type success: str
        """
        
        super(SyncStarRocksUsersResponse, self).__init__()

        self._success = None
        self.discriminator = None

        if success is not None:
            self.success = success

    @property
    def success(self):
        """Gets the success of this SyncStarRocksUsersResponse.

        开启行列分流是否成功。

        :return: The success of this SyncStarRocksUsersResponse.
        :rtype: str
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this SyncStarRocksUsersResponse.

        开启行列分流是否成功。

        :param success: The success of this SyncStarRocksUsersResponse.
        :type success: str
        """
        self._success = success

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncStarRocksUsersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/sync_star_rocks_users_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SyncStarRocksUsersResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'success': 'str'
    }

    attribute_map = {
        'success': 'success'
    }

    def __init__(self, success=None):
        r"""SyncStarRocksUsersResponse

        The model defined in huaweicloud sdk

        :param success: 开启行列分流是否成功。
        :type success: str
        """
        
        super(SyncStarRocksUsersResponse, self).__init__()

        self._success = None
        self.discriminator = None

        if success is not None:
            self.success = success

    @property
    def success(self):
        r"""Gets the success of this SyncStarRocksUsersResponse.

        开启行列分流是否成功。

        :return: The success of this SyncStarRocksUsersResponse.
        :rtype: str
        """
        return self._success

    @success.setter
    def success(self, success):
        r"""Sets the success of this SyncStarRocksUsersResponse.

        开启行列分流是否成功。

        :param success: The success of this SyncStarRocksUsersResponse.
        :type success: str
        """
        self._success = success

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncStarRocksUsersResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
